@@ -1,9 +1,11 @@
 use strict; #-*-CPerl-*-
 use warnings;
 
+use lib qw( ../../../lib );
+
 =head1 NAME
 
-    Algorithm::Evolutionary::Utils - Container module with a hodgepodge of functions
+Algorithm::Evolutionary::Utils - Container module with a hodgepodge of functions
                  
 =head1 SYNOPSIS
   
@@ -30,12 +32,12 @@ package Algorithm::Evolutionary::Utils;
 
 use Exporter;
 our @ISA = qw(Exporter);
-our $VERSION = ( '$Revision: 1.6 $ ' =~ /(\d+\.\d+)/ ) ;
-our @EXPORT_OK = qw( entropy consensus hamming random_bitstring);
+our ($VERSION) = ( '$Revision: 2.4 $ ' =~ /(\d+\.\d+)/ ) ;
+our @EXPORT_OK = qw( entropy consensus hamming random_bitstring parse_xml);
 
 use Carp;
 use String::Random;
-
+use XML::Parser;
 
 =head2 entropy( $population)
 
@@ -112,16 +114,30 @@ sub random_bitstring {
   return $generator->randregex($regex);
 }
 
+=head2 parse_xml( $string ) 
+
+Parses the string and returns an XML tree
+
+=cut
+
+sub parse_xml {
+  my $string = shift || croak "No string to parse!\n";
+  my $p=new XML::Parser(Style=>'EasyTree');
+  $XML::Parser::EasyTree::Noempty=1;
+  my $xml_dom = $p->parse($string) || croak "Problems parsing $string: $!\n";
+  return $xml_dom;
+}
+
 
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/10/24 07:56:00 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Utils.pm,v 1.6 2008/10/24 07:56:00 jmerelo Exp $ 
+  CVS Info: $Date: 2009/02/07 18:31:28 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Utils.pm,v 2.4 2009/02/07 18:31:28 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.6 $
+  $Revision: 2.4 $
   $Name $
 
 =cut
